-- 202200875 DDL (ACM)

-- T_F_INV_1_REF
CREATE TABLE ACM.T_F_INV_1_REF
(
  REF_KEY           VARCHAR2(108 BYTE)          NOT NULL,
  USAGE             VARCHAR2(40 BYTE)           NOT NULL,
  CODE              VARCHAR2(20 BYTE)           NOT NULL,
  DISPLAY           VARCHAR2(4000 BYTE)         NOT NULL,
  SEQ               NUMBER,
  ACTIVE            VARCHAR2(1 BYTE)            DEFAULT 'Y'                   NOT NULL,
  DEV_COMMENT       VARCHAR2(4000 BYTE),
  CREATED_BY        VARCHAR2(100 BYTE),
  CREATED_ON        DATE,
  LAST_MODIFIED_BY  VARCHAR2(100 BYTE),
  LAST_MODIFIED_ON  DATE,
  OBJ_TYPE          NUMBER(38),
  DATA_GROUP_ID     NUMBER                      NOT NULL
)
TABLESPACE ACM_DATA;

COMMENT ON TABLE ACM.T_F_INV_1_REF IS '[ABBREV:INV_1_REF] All of the reference data that can be represented with a simple code/display pair for the INV_1 File.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.REF_KEY IS 'A composite primary key composed of the object type code (if not null) + usage + code. If you ever need to change the usage or code, I recommend inserting a new row and deleting the old one after making sure all references have been updated.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.USAGE IS 'Used to segregate ref data into unique meaningful groups.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.CODE IS 'The key by which this row is identified programmatically. Not usually visible to the end-user.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.DISPLAY IS 'The user-visible value that identifies this row.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.SEQ IS 'Used to explicitly order the rows in the table, often for lookup purposes.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.ACTIVE IS 'Indicates whether this row is currently "active" (and thus still useable).';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.DEV_COMMENT IS 'Internal documentation describing this flag.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.LAST_MODIFIED_BY IS 'The name of the Personnel that last modified this row.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.LAST_MODIFIED_ON IS 'The date/time this row was last modified.';

COMMENT ON COLUMN ACM.T_F_INV_1_REF.OBJ_TYPE IS 'FK to T_ACM_OBJ_TYPE. Gets appended to the REF_KEY if it is not null. Allows reference data (that does not drive any functionality) to link to an Object Type that it is specific to.';


CREATE INDEX ACM.I_INV_1_REF_USAGE ON ACM.T_F_INV_1_REF
(USAGE)
TABLESPACE ACM_INDX;


CREATE UNIQUE INDEX ACM.PK_INV_1_REF ON ACM.T_F_INV_1_REF
(REF_KEY)
TABLESPACE ACM_INDX;


CREATE UNIQUE INDEX ACM.UK_INV_1_REF_USAGE_CODE_OBJTYPE ON ACM.T_F_INV_1_REF
(USAGE, CODE, OBJ_TYPE)
TABLESPACE ACM_INDX;


CREATE OR REPLACE TRIGGER F_INV_1_REF_B_IUD BEFORE
    INSERT OR UPDATE ON T_F_INV_1_REF
    FOR EACH ROW
DECLARE
    V_REF_KEY_CHANGED BOOLEAN := FALSE;
BEGIN
    IF INSERTING THEN
        SET_TABLE_ROW_VALS_NO_SID(:NEW.CREATED_ON,:NEW.CREATED_BY,:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY);
    END IF;
    IF INSERTING OR UPDATING THEN
        :NEW.USAGE := REGEXP_REPLACE(
            :NEW.USAGE,
            '[^A-Z_0-9]',
            ''
        );
        :NEW.CODE := REGEXP_REPLACE(
            :NEW.CODE,
            '[^A-Z_0-9]',
            ''
        );
        IF :NEW.OBJ_TYPE IS NULL THEN
            :NEW.REF_KEY := :NEW.USAGE || '.' || :NEW.CODE;
        ELSE
            :NEW.REF_KEY := ACM_OBJ.GET_OBJTYPE_CODE(:NEW.OBJ_TYPE)|| '.' || :NEW.USAGE || '.' || :NEW.CODE;
        END IF;
        :NEW.REF_KEY := UPPER(:NEW.REF_KEY);
    END IF;
    IF UPDATING THEN
        SET_TABLE_ROW_MOD_VALS(:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY);
    END IF;
END;
/


CREATE OR REPLACE TRIGGER ACM.BI_INV_1_REFERENCE_DG before insert ON ACM.T_F_INV_1_REF for each row
declare  begin  if :NEW.data_group_id is null then :NEW.data_group_id := sync_util.dg_from_instance; end if;  end;
/


CREATE OR REPLACE TRIGGER ACM.BD_INV_1_REFERENCE_AUD before delete ON ACM.T_F_INV_1_REF for each row
begin if sync_util.dg_from_instance=1 then insert into t_sync_del_rows(table_name,del_id)values('T_F_INV_1_REF',:OLD.REF_KEY); end if; end;
/


ALTER TABLE ACM.T_F_INV_1_REF ADD (
  CONSTRAINT CK_INV_1_REF_ACTIVE_YN
  CHECK (ACTIVE IN ('Y','N')),
  CONSTRAINT PK_INV_1_REF
  PRIMARY KEY
  (REF_KEY)
  USING INDEX ACM.PK_INV_1_REF,
  CONSTRAINT UK_INV_1_REF_USAGE_CODE_OBJTYPE
  UNIQUE (USAGE, CODE, OBJ_TYPE)
  USING INDEX ACM.UK_INV_1_REF_USAGE_CODE_OBJTYPE);

ALTER TABLE ACM.T_F_INV_1_REF ADD (
  CONSTRAINT FK_INV_1_REF_OBJ_TYPE 
  FOREIGN KEY (OBJ_TYPE) 
  REFERENCES ACM.T_ACM_OBJ_TYPE (SID)
  ON DELETE CASCADE);

GRANT SELECT ON ACM.T_F_INV_1_REF TO ADV_SEARCH;

-- T_F_IT_DISPOSITION_REF
CREATE TABLE ACM.T_F_IT_DISPOSITION_REF
(
  SID               NUMBER                      NOT NULL,
  CODE              VARCHAR2(20 BYTE)           NOT NULL,
  DISPLAY           VARCHAR2(100 BYTE),
  SEQ               NUMBER,
  CREATED_BY        VARCHAR2(100 BYTE),
  CREATED_ON        DATE,
  LAST_MODIFIED_BY  VARCHAR2(100 BYTE),
  LAST_MODIFIED_ON  DATE
)
TABLESPACE ACM_DATA;


CREATE UNIQUE INDEX ACM.T_F_IT_DISPOSITION_REF_PK ON ACM.T_F_IT_DISPOSITION_REF
(SID)
TABLESPACE ACM_INDX;


CREATE UNIQUE INDEX ACM.UK_F_IT_DISPOSITION_REF_CODE ON ACM.T_F_IT_DISPOSITION_REF
(CODE)
TABLESPACE ACM_INDX;


CREATE OR REPLACE TRIGGER ACM.F_IT_DISPOSITION_REF BEFORE
    INSERT OR UPDATE OR DELETE ON ACM.T_F_IT_DISPOSITION_REF     FOR EACH ROW
BEGIN
    IF INSERTING THEN
        SET_TABLE_ROW_VALS(:NEW.CREATED_ON,:NEW.CREATED_BY,:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY,:NEW.SID);
    END IF;
    IF UPDATING THEN
        SET_TABLE_ROW_MOD_VALS(:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY);
    END IF;
END;
/


CREATE OR REPLACE TRIGGER ACM.BD_F_IT_DISPOSITION_REF_AUD before delete ON ACM.T_F_IT_DISPOSITION_REF for each row
begin if sync_util.dg_from_instance=1 then insert into t_sync_del_rows(table_name,del_id)values('T_F_IT_DISPOSITION_REF',:OLD.SID); end if; end;
/


ALTER TABLE ACM.T_F_IT_DISPOSITION_REF ADD (
  CONSTRAINT T_F_IT_DISPOSITION_REF_PK
  PRIMARY KEY
  (SID)
  USING INDEX ACM.T_F_IT_DISPOSITION_REF_PK,
  CONSTRAINT UK_F_IT_DISPOSITION_REF_CODE
  UNIQUE (CODE)
  USING INDEX ACM.UK_F_IT_DISPOSITION_REF_CODE);

GRANT SELECT ON ACM.T_F_IT_DISPOSITION_REF TO ADV_SEARCH;

-- T_F_IT_DISPOSITION
CREATE TABLE ACM.T_F_IT_DISPOSITION
(
  SID               NUMBER                      NOT NULL,
  OBJ               VARCHAR2(20 BYTE)           NOT NULL,
  RESOLVED          VARCHAR2(1 BYTE),
  DISPOSITION       NUMBER,
  OTHER_AGENCY      VARCHAR2(400 BYTE),
  COMMENTS          CLOB,
  CREATED_BY        VARCHAR2(100 BYTE),
  CREATED_ON        DATE,
  LAST_MODIFIED_BY  VARCHAR2(100 BYTE),
  LAST_MODIFIED_ON  DATE,
  DATA_GROUP_ID     NUMBER                      NOT NULL
)
TABLESPACE ACM_DATA;


CREATE UNIQUE INDEX ACM.T_F_IT_DISPOSITION_PK ON ACM.T_F_IT_DISPOSITION
(SID)
TABLESPACE ACM_INDX;


CREATE UNIQUE INDEX ACM.UK_F_IT_DISPOSITION_OBJ ON ACM.T_F_IT_DISPOSITION
(OBJ)
TABLESPACE ACM_INDX;


CREATE OR REPLACE TRIGGER ACM.BI_F_IT_DISPOSITION_DG before insert ON ACM.T_F_IT_DISPOSITION for each row
declare  begin  if :NEW.data_group_id is null then :NEW.data_group_id := sync_util.dg_from_instance; end if;  end;
/


CREATE OR REPLACE TRIGGER ACM.BD_F_IT_DISPOSITION_AUD before delete ON ACM.T_F_IT_DISPOSITION for each row
begin if sync_util.dg_from_instance=1 then insert into t_sync_del_rows(table_name,del_id)values('T_F_IT_DISPOSITION',:OLD.SID); end if; end;
/


CREATE OR REPLACE TRIGGER ACM.F_IT_DISPOSITION BEFORE
    INSERT OR UPDATE OR DELETE ON ACM.T_F_IT_DISPOSITION     FOR EACH ROW
BEGIN
    IF INSERTING THEN
        SET_TABLE_ROW_VALS(:NEW.CREATED_ON,:NEW.CREATED_BY,:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY,:NEW.SID);
    END IF;
    IF UPDATING THEN
        SET_TABLE_ROW_MOD_VALS(:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY);
    END IF;
END;
/


ALTER TABLE ACM.T_F_IT_DISPOSITION ADD (
  CONSTRAINT PK_F_IT_DISPOSITION
  PRIMARY KEY
  (SID)
  USING INDEX ACM.T_F_IT_DISPOSITION_PK,
  CONSTRAINT UK_F_IT_DISPOSITION_OBJ
  UNIQUE (OBJ)
  USING INDEX ACM.UK_F_IT_DISPOSITION_OBJ);

ALTER TABLE ACM.T_F_IT_DISPOSITION ADD (
  CONSTRAINT FK_F_IT_DISPOSITION_DISPOSITION 
  FOREIGN KEY (DISPOSITION) 
  REFERENCES ACM.T_F_IT_DISPOSITION_REF (SID),
  CONSTRAINT FK_F_IT_DISPOSITION_OBJ 
  FOREIGN KEY (OBJ) 
  REFERENCES ACM.T_ACM_OBJ (SID)
  ON DELETE CASCADE);

GRANT SELECT ON ACM.T_F_IT_DISPOSITION TO ADV_SEARCH;

-- T_F_IT_MATTER
CREATE TABLE ACM.T_F_IT_MATTER
(
  SID               NUMBER                      NOT NULL,
  OBJ               VARCHAR2(20 BYTE)           NOT NULL,
  MATTER            VARCHAR2(108 BYTE)          NOT NULL,
  MATTER_SUBTYPE    VARCHAR2(108 BYTE)          NOT NULL,
  PRIORITY          VARCHAR2(108 BYTE),
  COUNTRY           VARCHAR2(108 BYTE),
  INCIDENT_CITY     VARCHAR2(200 BYTE),
  INCIDENT_DATE     DATE,
  REPORTED_DATE     DATE,
  CREATED_BY        VARCHAR2(100 BYTE),
  CREATED_ON        DATE,
  LAST_MODIFIED_BY  VARCHAR2(100 BYTE),
  LAST_MODIFIED_ON  DATE,
  RESOLVED          VARCHAR2(1 BYTE)            DEFAULT null,
  STATE             VARCHAR2(400 BYTE),
  DATA_GROUP_ID     NUMBER                      NOT NULL
)
TABLESPACE ACM_DATA;


CREATE INDEX ACM.I_F_IT_MATTER_MATTER ON ACM.T_F_IT_MATTER
(MATTER)
TABLESPACE ACM_INDX;

CREATE INDEX ACM.I_F_IT_MATTER_MATTER_SBTP ON ACM.T_F_IT_MATTER
(MATTER_SUBTYPE)
TABLESPACE ACM_INDX;

CREATE INDEX ACM.I_F_IT_MATTER_PRIORITY ON ACM.T_F_IT_MATTER
(PRIORITY)
TABLESPACE ACM_INDX;


CREATE INDEX ACM.I_F_IT_MATTER_STATE ON ACM.T_F_IT_MATTER
(STATE, 1)
TABLESPACE ACM_INDX;


CREATE UNIQUE INDEX ACM.PK_F_IT_MATTER ON ACM.T_F_IT_MATTER
(SID)
TABLESPACE ACM_INDX;


CREATE OR REPLACE TRIGGER ACM.BI_F_IT_MATTER_DG before insert ON ACM.T_F_IT_MATTER for each row
declare  begin  if :NEW.data_group_id is null then :NEW.data_group_id := sync_util.dg_from_instance; end if;  end;
/


CREATE OR REPLACE TRIGGER ACM.BD_F_IT_MATTER_AUD before delete ON ACM.T_F_IT_MATTER for each row
begin if sync_util.dg_from_instance=1 then insert into t_sync_del_rows(table_name,del_id)values('T_F_IT_MATTER',:OLD.SID); end if; end;
/


CREATE OR REPLACE TRIGGER ACM.F_IT_MATTER_B_IUD BEFORE
    INSERT OR UPDATE ON ACM.T_F_IT_MATTER     FOR EACH ROW
BEGIN
    IF INSERTING THEN
        SET_TABLE_ROW_VALS(:NEW.CREATED_ON,:NEW.CREATED_BY,:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY,:NEW.SID);
    END IF;
    IF UPDATING THEN
        SET_TABLE_ROW_MOD_VALS(:NEW.LAST_MODIFIED_ON,:NEW.LAST_MODIFIED_BY);
    END IF;
END;
/


ALTER TABLE ACM.T_F_IT_MATTER ADD (
  CONSTRAINT PK_F_IT_MATTER
  PRIMARY KEY
  (SID)
  USING INDEX ACM.PK_F_IT_MATTER);

ALTER TABLE ACM.T_F_IT_MATTER ADD (
  CONSTRAINT FK_F_IT_MATTER_MATTER 
  FOREIGN KEY (MATTER) 
  REFERENCES ACM.T_F_INV_1_REF (REF_KEY),
  CONSTRAINT FK_F_IT_MATTER_MATTER_SBTP 
  FOREIGN KEY (MATTER_SUBTYPE) 
  REFERENCES ACM.T_F_INV_1_REF (REF_KEY),
  CONSTRAINT FK_F_IT_MATTER_CTRY 
  FOREIGN KEY (COUNTRY) 
  REFERENCES ACM.T_ACM_REF_CTRY (ISO_3166_1_ALPHA_2),
  CONSTRAINT FK_F_IT_MATTER_OBJ 
  FOREIGN KEY (OBJ) 
  REFERENCES ACM.T_ACM_OBJ (SID)
  ON DELETE CASCADE,
  CONSTRAINT FK_F_IT_MATTER_PRIORITY 
  FOREIGN KEY (PRIORITY) 
  REFERENCES ACM.T_F_ALLEG_PRIORITY (REF_KEY)
  ON DELETE CASCADE,
  CONSTRAINT FK_F_IT_MATTER_STATE 
  FOREIGN KEY (STATE) 
  REFERENCES ACM.T_ACM_REF_CTRY_DIVISION (REF_KEY));

GRANT SELECT ON ACM.T_F_IT_MATTER TO ADV_SEARCH;

-- Plugins: CI Indicator -> IT Matter; Disposition to IT Disposition
create or replace PACKAGE ACM_P_IT_MATTER as
/** Summary
<table>
<tr><td>12/23/2019</td><td>LLSB</td><td>Copied Attachment Plugin Source to here.</td></tr>
</table>
*/
/** Summary
<table>
<tr><td>12/23/2019</td><td>LLSB</td><td>Created</td></tr>
</table>
*/
FUNCTION I2MS_IT_MATTER_REGION_RENDER (
        P_REGION IN APEX_PLUGIN.T_REGION,
        P_PLUGIN IN APEX_PLUGIN.T_PLUGIN,
        P_IS_PRINTER_FRIENDLY IN BOOLEAN
    ) RETURN APEX_PLUGIN.T_REGION_RENDER_RESULT;
/** Summary
<table>
<tr><td>12/23/2019</td><td>LLSB</td><td>Created</td></tr>
</table>
*/
    FUNCTION I2MS_IT_MATTER_REGION_AJAX (
        P_REGION IN APEX_PLUGIN.T_REGION,
        P_PLUGIN IN APEX_PLUGIN.T_PLUGIN
    ) RETURN APEX_PLUGIN.T_REGION_AJAX_RESULT;
/** BPE Condition checking file has at least one IT Matter
<table>
<tr><td>8/13/2018</td><td>KDB</td><td>Created.</td></tr>
</table>
*/
    FUNCTION COND_FILE_IT_MATTER RETURN VARCHAR2;
end ACM_P_IT_MATTER;
/

create or replace PACKAGE BODY     ACM_P_IT_MATTER AS
/** Summary
<table>
<tr><td>12/23/2019</td><td>LLSB</td><td>Created</td></tr>
</table>
*/
/** Summary
<table>
<tr><td>12/23/2019</td><td>LLSB</td><td>Created</td></tr>
</table>
*/
    PROCEDURE PRINT_REPORT (
        P_OBJ IN VARCHAR2, P_REGION IN APEX_PLUGIN.T_REGION, P_PLUGIN IN APEX_PLUGIN.T_PLUGIN, P_PG_NUM IN VARCHAR2 := NULL
    ) IS
        L_RSLT_INDX NUMBER := 0;
        L_EDIT_AUTH VARCHAR2(10) := 'N';
		L_PG_NUM VARCHAR2(10) := NULL;
    BEGIN
        L_EDIT_AUTH := ACM_BPE.CHECK_ACTION('EDIT_ALLEG', P_OBJ);
        HTP.DIV(CATTRIBUTES => 'id="report_' || P_REGION.ID || '_catch"');
		IF P_PG_NUM IS NULL THEN
			L_PG_NUM := '5027';
		ELSE
			L_PG_NUM := P_PG_NUM;
		END IF;
        FOR ITM IN (
            SELECT TFIM.SID, TFIR.DISPLAY MATTER, TFIR1.DISPLAY MATTER_SUBTYPE, TFAP.DISPLAY PRIORITY, TARC.DISPLAY COUNTRY, TARCD.DIVISION_DISPLAY STATE, TFIM.INCIDENT_CITY, TFIM.INCIDENT_DATE,
            TFIM.REPORTED_DATE, TFIM.CREATED_BY, TFIM.CREATED_ON, TFIM.LAST_MODIFIED_BY, TFIM.LAST_MODIFIED_ON
            FROM T_F_IT_MATTER TFIM
            INNER JOIN T_F_INV_1_REF TFIR ON TFIM.MATTER = TFIR.REF_KEY AND TFIM.OBJ = P_OBJ AND TFIR.OBJ_TYPE = ACM_OBJ.GET_OBJTYPE(
            P_OBJ)
            INNER JOIN T_F_INV_1_REF TFIR1 ON TFIM.MATTER_SUBTYPE = TFIR1.REF_KEY AND TFIM.OBJ = P_OBJ AND TFIR1.OBJ_TYPE = ACM_OBJ.GET_OBJTYPE(
            P_OBJ)
            LEFT OUTER JOIN T_ACM_REF_CTRY TARC ON TARC.ISO_3166_1_ALPHA_2 = TFIM.COUNTRY
            LEFT OUTER JOIN T_ACM_REF_CTRY_DIVISION TARCD ON TARCD.REF_KEY = TFIM.STATE
            LEFT OUTER JOIN T_F_ALLEG_PRIORITY TFAP ON TFAP.REF_KEY = TFIM.PRIORITY
            ORDER BY TFIR.SEQ, TFIM.CREATED_ON DESC
        ) LOOP
            L_RSLT_INDX := L_RSLT_INDX + 1;
            IF L_RSLT_INDX = 1 THEN
                ACM_REGION_UTIL.START_TABLE(P_REGION.ID, 'IT Categories');
                IF L_EDIT_AUTH = 'Y' THEN
                    ACM_REGION_UTIL.THC('Edit', 'SID');
                ELSE
                    ACM_REGION_UTIL.THC('View', 'SID');
                END IF;
                ACM_REGION_UTIL.THC('IT Category', 'MATTER');
                ACM_REGION_UTIL.THC('IT Sub-Category', 'MATTER_SUBTYPE');
                ACM_REGION_UTIL.THC('Priority', 'PRIORITY');
                ACM_REGION_UTIL.THC('Country', 'COUNTRY');
                ACM_REGION_UTIL.THC('State', 'STATE');
                ACM_REGION_UTIL.THC('City', 'INCIDENT_CITY');
                ACM_REGION_UTIL.THC('Incident Date', 'INCIDENT_DATE');
                ACM_REGION_UTIL.THC('Reported On', 'REPORTED_DATE');
                ACM_REGION_UTIL.THC_SORTED('Created On', 'CREATED_ON');
                HTP.TABLEROWCLOSE;
                HTP.P('</thead>');
                HTP.P('<tbody>');
            END IF;
            HTP.TABLEROWOPEN();
            ACM_REGION_UTIL.TD('<a href="' || PREPARE_URL(L_PG_NUM, L_PG_NUM, 'P' || L_PG_NUM || '_SID,P' || L_PG_NUM || '_OBJ', ITM.SID || ',' || P_OBJ,P_REGION.STATIC_ID) || '">' ||
                CASE
                    WHEN L_EDIT_AUTH = 'Y' THEN
                        ACM_REGION_UTIL.EDIT_IMAGE('Edit IT Category')
                    ELSE ACM_REGION_UTIL.VIEW_IMAGE('View IT Category')
                END
                               || '</a>', 'SID');
            ACM_REGION_UTIL.TD(ITM.MATTER, 'MATTER');
            ACM_REGION_UTIL.TD(ITM.MATTER_SUBTYPE, 'MATTER_SUBTYPE');
            ACM_REGION_UTIL.TD(ITM.PRIORITY, 'PRIORITY');
            ACM_REGION_UTIL.TD(ITM.COUNTRY, 'COUNTRY');
            ACM_REGION_UTIL.TD(ITM.STATE, 'STATE');
            ACM_REGION_UTIL.TD(ITM.INCIDENT_CITY, 'INCIDENT_CITY');
            ACM_REGION_UTIL.TD(TO_CHAR(ITM.INCIDENT_DATE, FMT_DATE), 'INCIDENT_DATE');
            ACM_REGION_UTIL.TD(TO_CHAR(ITM.REPORTED_DATE, FMT_DATE), 'REPORTED_DATE');
            ACM_REGION_UTIL.TD(TO_CHAR(ITM.CREATED_ON, FMT_DATE), 'CREATED_ON');
            HTP.TABLEROWCLOSE;
        END LOOP;
        IF L_RSLT_INDX > 0 THEN
            HTP.P('</tbody>');
            HTP.TABLECLOSE;
            HTP.P('</div>');
            HTP.P('</div>');
            HTP.P('</div>');
        ELSE
            ACM_REGION_UTIL.NDF('No IT Categories added.');
        END IF;
        HTP.P('</div>');
    END;
/** Summary
<table>
<tr><td>12/23/2019</td><td>LLSB</td><td>Created</td></tr>
</table>
*/
    FUNCTION I2MS_IT_MATTER_REGION_RENDER (
        P_REGION IN APEX_PLUGIN.T_REGION, P_PLUGIN IN APEX_PLUGIN.T_PLUGIN, P_IS_PRINTER_FRIENDLY IN BOOLEAN
    ) RETURN APEX_PLUGIN.T_REGION_RENDER_RESULT IS
        L_RTN APEX_PLUGIN.T_REGION_RENDER_RESULT;
        L_OBJ T_ACM_OBJ.SID%TYPE;
		L_PG_NUM VARCHAR2(10) := NULL;
   --P_REGION.ATTRIBUTE_01 PAGE ITEM OBJ, NECESSARY FOR GETTING VALUES FOR THE REPORT
   --P_REGION.ATTRIBUTE_02 TARGET PAGE, USED TO DIRECT TO SECONDARY PAGE
    BEGIN
        L_OBJ := APEX_UTIL.GET_SESSION_STATE(P_REGION.ATTRIBUTE_01);
		L_PG_NUM := P_REGION.ATTRIBUTE_02;
		IF L_PG_NUM IS NULL THEN
			L_PG_NUM := '5027';
		END IF;
        IF ACM_BPE.CHECK_ACTION('ADD_ALLEG', L_OBJ) = 'Y' THEN
			ACM_REGION_UTIL.PRINT_BUTTON(PREPARE_URL(L_PG_NUM, L_PG_NUM, 'P' || L_PG_NUM ||'_OBJ', L_OBJ), 'B' || P_REGION.ID || '-add-allegation',
				'add-allegation', 'Add IT Category');
        END IF;
        PRINT_REPORT(L_OBJ, P_REGION, P_PLUGIN, L_PG_NUM);
        ACM_REGION_UTIL.ADD_ONLOAD_JS(P_REGION, P_REGION.ATTRIBUTE_01);
        RETURN L_RTN;
    END I2MS_IT_MATTER_REGION_RENDER;
/** Summary
<table>
<tr><td>12/23/2019</td><td>LLSB</td><td>Created</td></tr>
</table>
*/
    FUNCTION I2MS_IT_MATTER_REGION_AJAX (
        P_REGION IN APEX_PLUGIN.T_REGION, P_PLUGIN IN APEX_PLUGIN.T_PLUGIN
    ) RETURN APEX_PLUGIN.T_REGION_AJAX_RESULT IS
        L_RTN APEX_PLUGIN.T_REGION_AJAX_RESULT;
        L_OBJ T_ACM_OBJ.SID%TYPE;
		L_PG_NUM VARCHAR2(10) := NULL;
    BEGIN
        L_OBJ := APEX_UTIL.GET_SESSION_STATE(P_REGION.ATTRIBUTE_01);
		L_PG_NUM := P_REGION.ATTRIBUTE_02;
        PRINT_REPORT(L_OBJ, P_REGION, P_PLUGIN, L_PG_NUM);
        RETURN L_RTN;
    END I2MS_IT_MATTER_REGION_AJAX;
/** BPE Condition checking file has at least one IT Matter
<table>
<tr><td>8/13/2018</td><td>KDB</td><td>Created.</td></tr>
</table>
*/
    FUNCTION COND_FILE_IT_MATTER RETURN VARCHAR2 IS
    BEGIN
        FOR RSLT IN (
            SELECT SID
            FROM T_F_IT_MATTER AO
            INNER JOIN T_F_ALLEG_PRIORITY AP ON AP.REF_KEY = AO.PRIORITY
            WHERE AO.OBJ = ACM_BPE.GET_PARAM('OBJ') AND AP.CODE = 'PRIMARY'
        ) LOOP
            RETURN 'Y';
        END LOOP;
        RETURN 'File must have a IT Matter with a Primary priority.';
    END COND_FILE_IT_MATTER;
END ACM_P_IT_MATTER;
/

create or replace package ACM_P_IT_DISPOSITION as 
/** Summary
<table>
<tr><td>1/28/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
/** Summary
<table>
<tr><td>1/28/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION I2MS_IT_DISPOSITION_REGION_RENDER(
        P_REGION IN APEX_PLUGIN.T_REGION,
        P_PLUGIN IN APEX_PLUGIN.T_PLUGIN,
        P_IS_PRINTER_FRIENDLY IN BOOLEAN
    )RETURN APEX_PLUGIN.T_REGION_RENDER_RESULT;
/** Summary
<table>
<tr><td>1/28/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION I2MS_IT_DISPOSITION_REGION_AJAX(
        P_REGION IN APEX_PLUGIN.T_REGION,
        P_PLUGIN IN APEX_PLUGIN.T_PLUGIN
    )RETURN APEX_PLUGIN.T_REGION_AJAX_RESULT;
/** Summary
<table>
<tr><td>1/28/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION COND_AT_LEAST_ONE_DISP RETURN VARCHAR2;
/** Summary
<table>
<tr><td>1/28/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION COND_DISP_EXPLANATION RETURN VARCHAR2;
/** Summary
<table>
<tr><td>12/12/2019</td><td>DL</td><td>Created</td></tr>
</table>
*/
    FUNCTION COND_DISP_RESOLVE RETURN VARCHAR2;
end ACM_P_IT_DISPOSITION;
/

create or replace package body     ACM_P_IT_DISPOSITION as
/** Summary
*<table>
<tr><td>1/25/2019</td><td>KDB</td><td>Created</td></tr>
*</table>
*/
/** Summary
<table>
<tr><td>1/25/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    PROCEDURE PRINT_REPORT(
        P_OBJ IN VARCHAR2,
        P_REGION IN APEX_PLUGIN.T_REGION,
        P_PLUGIN IN APEX_PLUGIN.T_PLUGIN
    )IS
        L_DISP_EXISTS BOOLEAN := FALSE;
        L_EDIT_AUTH VARCHAR2(1) := 'N';
    BEGIN
        IF APEX_APPLICATION.G_DEBUG THEN
            APEX_DEBUG.INFO('...Printing report.');
        END IF;
        IF ACM_BPE.CHECK_ACTION('SAVE',P_OBJ) = 'Y' THEN
            L_EDIT_AUTH := 'Y';
        END IF;
        HTP.DIV(CATTRIBUTES => 'id="report_' || P_REGION.ID || '_catch"');
        --PRINT FIELDS
            FOR DISP IN (SELECT D.SID, DECODE(D.RESOLVED,'Y','Yes','N','No') RESOLVED,R.DISPLAY DISP_DISPLAY,D.OTHER_AGENCY,D.COMMENTS 
                        FROM T_F_IT_DISPOSITION D 
                        LEFT OUTER JOIN T_F_IT_DISPOSITION_REF R ON R.SID = D.DISPOSITION 
                        WHERE OBJ = P_OBJ)
            LOOP
                L_DISP_EXISTS := TRUE;
                IF L_EDIT_AUTH = 'Y' THEN
                    ACM_REGION_UTIL.PRINT_BUTTON(PREPARE_URL('5026','5026','P5026_SID',DISP.SID,P_REGION.STATIC_ID),'B' || P_REGION.ID || '-edit-disposition','edit-disposition','Edit Disposition');
                END IF;
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Resolved:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange">' || DISP.RESOLVED || '</span>');
                    HTP.P('</div>');
                HTP.P('</div>');
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Disposition:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange">' || DISP.DISP_DISPLAY || '</span>');
                    HTP.P('</div>');
                HTP.P('</div>');
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Other Agency:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange">' || DISP.OTHER_AGENCY || '</span>');
                    HTP.P('</div>');
                HTP.P('</div>');
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Explain Disposition:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange">' || DISP.COMMENTS || '</span>');
                    HTP.P('</div>');
                HTP.P('</div>');
            END LOOP;
            IF NOT L_DISP_EXISTS THEN
                IF L_EDIT_AUTH = 'Y' THEN
                    ACM_REGION_UTIL.PRINT_BUTTON(PREPARE_URL('5026','5026','P5026_OBJ',P_OBJ),'B' || P_REGION.ID || '-add-disposition','add-disposition','Add Disposition');
                END IF;
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Resolved:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange"></span>');
                    HTP.P('</div>');
                HTP.P('</div>');
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Disposition:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange"></span>');
                    HTP.P('</div>');
                HTP.P('</div>');
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Other Agency:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange"></span>');
                    HTP.P('</div>');
                HTP.P('</div>');
                HTP.P('<div class="t-Form-fieldContainer rel-col">');
                    HTP.P('<div class="t-Form-labelContainer col col-null">');
                        HTP.P('<label class="t-Form-label">Explain Disposition:</label>');
                    HTP.P('</div>');
                    HTP.P('<div class="t-Form-inputContainer col col-null">');
                        HTP.P('<span class="display_only apex-item-display-only js-ignoreChange"></span>');
                    HTP.P('</div>');
                HTP.P('</div>');
            END IF;
        HTP.P('</div>');
    END;
/** Summary
<table>
<tr><td>1/25/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION I2MS_IT_DISPOSITION_REGION_RENDER(
        P_REGION IN APEX_PLUGIN.T_REGION,
        P_PLUGIN IN APEX_PLUGIN.T_PLUGIN,
        P_IS_PRINTER_FRIENDLY IN BOOLEAN
    )RETURN APEX_PLUGIN.T_REGION_RENDER_RESULT IS
        V_RTN APEX_PLUGIN.T_REGION_RENDER_RESULT;
   --P_REGION.ATTRIBUTE_01 PAGE ITEM OBJ, NECESSARY FOR GETTING VALUES FOR THE REPORT
    BEGIN
        APEX_DEBUG.INFO('..Rendering report');
        PRINT_REPORT(V(P_REGION.ATTRIBUTE_01),P_REGION,P_PLUGIN);
        ACM_REGION_UTIL.ADD_ONLOAD_JS(P_REGION,P_REGION.ATTRIBUTE_01);
        RETURN V_RTN;
    END I2MS_IT_DISPOSITION_REGION_RENDER;
/** Summary
<table>
<tr><td>1/25/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION I2MS_IT_DISPOSITION_REGION_AJAX(
        P_REGION IN APEX_PLUGIN.T_REGION,
        P_PLUGIN IN APEX_PLUGIN.T_PLUGIN
    )RETURN APEX_PLUGIN.T_REGION_AJAX_RESULT IS
        V_RTN APEX_PLUGIN.T_REGION_AJAX_RESULT;
    BEGIN
        APEX_DEBUG.INFO('..Refreshing report');
        PRINT_REPORT(V(P_REGION.ATTRIBUTE_01),P_REGION,P_PLUGIN);
        RETURN V_RTN;
    END I2MS_IT_DISPOSITION_REGION_AJAX;
/** Summary
<table>
<tr><td>1/28/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION COND_AT_LEAST_ONE_DISP RETURN VARCHAR2 IS
        V_RTN VARCHAR2(400) := 'Y';
    BEGIN
        FOR RSLT IN (SELECT O.SID,R.DISPOSITION FROM T_ACM_OBJ O LEFT OUTER JOIN T_F_IT_DISPOSITION R ON R.OBJ = O.SID WHERE O.SID = ACM_BPE.GET_PARAM('OBJ') AND ROWNUM = 1)
        LOOP
            IF RSLT.DISPOSITION IS NULL THEN
                V_RTN := 'Must have a Disposition.';
            END IF;
        END LOOP;
        RETURN V_RTN;
    END COND_AT_LEAST_ONE_DISP;
/** Summary
<table>
<tr><td>1/28/2019</td><td>KDB</td><td>Created</td></tr>
</table>
*/
    FUNCTION COND_DISP_EXPLANATION RETURN VARCHAR2 IS
        V_RTN VARCHAR2(400) := 'Y';
    BEGIN
        FOR RSLT IN (SELECT O.SID,R.COMMENTS FROM T_ACM_OBJ O LEFT OUTER JOIN T_F_IT_DISPOSITION R ON R.OBJ = O.SID WHERE O.SID = ACM_BPE.GET_PARAM('OBJ') AND ROWNUM = 1)
        LOOP
            IF RSLT.COMMENTS IS NULL THEN
                V_RTN := 'Explanation of Disposition Required.';
            END IF;
        END LOOP;
        RETURN V_RTN;
    END COND_DISP_EXPLANATION;
/** Summary
<table>
<tr><td>12/12/2019</td><td>DL</td><td>Created</td></tr>
</table>
*/
    FUNCTION COND_DISP_RESOLVE RETURN VARCHAR2 IS
        V_RTN VARCHAR2(400) := 'Y';
    BEGIN
        FOR RSLT IN (SELECT O.SID,R.RESOLVED FROM T_ACM_OBJ O LEFT OUTER JOIN T_F_IT_DISPOSITION R ON R.OBJ = O.SID WHERE O.SID = ACM_BPE.GET_PARAM('OBJ') AND ROWNUM = 1)
        LOOP
            IF RSLT.RESOLVED IS NULL THEN
                V_RTN := 'File must have Resolution Response.';
            END IF;
        END LOOP;
        RETURN V_RTN;
    END COND_DISP_RESOLVE;
end ACM_P_IT_DISPOSITION;
/